summaryrefslogtreecommitdiffstats
path: root/chrome/browser/chromeos/tab_closeable_state_watcher.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/chromeos/tab_closeable_state_watcher.cc')
-rw-r--r--chrome/browser/chromeos/tab_closeable_state_watcher.cc11
1 files changed, 6 insertions, 5 deletions
diff --git a/chrome/browser/chromeos/tab_closeable_state_watcher.cc b/chrome/browser/chromeos/tab_closeable_state_watcher.cc
index 9346e86..e54f374 100644
--- a/chrome/browser/chromeos/tab_closeable_state_watcher.cc
+++ b/chrome/browser/chromeos/tab_closeable_state_watcher.cc
@@ -63,8 +63,9 @@ void TabCloseableStateWatcher::TabStripWatcher::TabChangedAt(
TabCloseableStateWatcher::TabCloseableStateWatcher()
: can_close_tab_(true),
signing_off_(false),
- bwsi_session_(
- CommandLine::ForCurrentProcess()->HasSwitch(switches::kBWSI)) {
+ guest_session_(
+ CommandLine::ForCurrentProcess()->HasSwitch(
+ switches::kGuestSession)) {
BrowserList::AddObserver(this);
notification_registrar_.Add(this, NotificationType::APP_EXITING,
NotificationService::AllSources());
@@ -185,7 +186,7 @@ void TabCloseableStateWatcher::CheckAndUpdateState(
} else { // There's only 1 normal browser.
if (!browser_to_check)
browser_to_check = tabstrip_watchers_[0]->browser();
- if (browser_to_check->profile()->IsOffTheRecord() && !bwsi_session_) {
+ if (browser_to_check->profile()->IsOffTheRecord() && !guest_session_) {
new_can_close = true;
} else {
TabStripModel* tabstrip_model = browser_to_check->tabstrip_model();
@@ -231,8 +232,8 @@ bool TabCloseableStateWatcher::CanCloseBrowserImpl(const Browser* browser,
return true;
// If last normal browser is incognito, open a non-incognito window,
- // and allow closing of incognito one (if not BWSI).
- if (browser->profile()->IsOffTheRecord() && !bwsi_session_) {
+ // and allow closing of incognito one (if not guest).
+ if (browser->profile()->IsOffTheRecord() && !guest_session_) {
*action_type = OPEN_WINDOW;
return true;
}